@@ -1,5 +1,8 @@
-from bson import json_util as json
+from Bubot.Helpers.Helper import get_tzinfo
 from aiohttp import web
+from bson.json_util import dumps, JSONOptions
+
+json_options = JSONOptions(tz_aware=True, tzinfo=get_tzinfo())
 
 
 class DeviceApi:
@@ -14,8 +17,8 @@ class WebResponse:
 
     @staticmethod
     def json_response(data, *, status: int = 200, headers=None, content_type: str = 'application/json',
-                      dumps=json.dumps) -> web.Response:
-        text = dumps(data, ensure_ascii=False)
+                      dumps=dumps) -> web.Response:
+        text = dumps(data, ensure_ascii=False, json_options=json_options)
         return web.Response(text=text, status=status, headers=headers, content_type=content_type)
 
     @staticmethod
